SimpleSpellCheckerCaRegister class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
registerLan()
→ void
-
this can be used to register manually the catalan
language to be supported by the
SimpleSpellChecker
-
removeLan()
→ void
-